==> kv5500-0.3.tar.gz: kv5500-0.3/src/kv5500_sms.hpp <==
/*****************************************************************************
 *
 *  kv5500_sms - read a sms from kv5500 like phone.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef KV5500_SMS_H
#define KV5500_SMS_H

#include <set>
#include <vector>

#include "sms.hpp"
#include "scanner.hpp"

/// If you send prefix 0xfe and postfix 0x7e, phone send some data.
///
/// fe 14 7e            Get sms. (size 565?) When call again, get next sms.
///                     But I don't know total sms number. If got all sms and
///                     call again, it will get last sms.
///
/// Need root permission to access usb on FreeBSD, maybe also in GNU/Linux. :(
namespace KV5500 {

    class UsbDev;

    class SMSScanner : public Scanner {
    public:
        SMSScanner();

        void GetSMS(std::vector<SMS>& sms) const;
        bool GetSMS(SMS& sms, unsigned int num) const;
        unsigned int GetSMSNum() const;

    private:
        std::set<int> dateSet_;
        std::vector<SMS> smsContainer_;

        SMSScanner(const SMSScanner&);
        SMSScanner& operator=(const SMSScanner&);

        bool DoScan(struct usb_device* dev);

        bool Request(UsbDev& udev);

        int Recv(UsbDev& udev);

        /// @brief Check existance by date string.
        bool CheckExist(const char* const buf);
    };

    /// @breif Get date string from buf. You need to delete return str.
    const char* GetSMSDateStr(const char* const buf);

    bool GetSMS(std::vector<SMS>& sms);
}

/// inline functions.
using namespace KV5500;

inline SMSScanner::SMSScanner()
{}

inline void SMSScanner::GetSMS(std::vector<SMS>& sms) const
{
    sms = smsContainer_;
}

inline bool SMSScanner::GetSMS(SMS& sms, unsigned int num) const
{
    if(smsContainer_.size() < num)
        return false;

    sms = smsContainer_[num];
}

inline unsigned int SMSScanner::GetSMSNum() const
{
    return smsContainer_.size();
}

#endif

==> kv5500-0.3.1.tar.gz: kv5500-0.3.1/src/kv5500_sms.hpp <==
/*****************************************************************************
 *
 *  kv5500_sms - read a sms from kv5500 like phone.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#ifndef KV5500_SMS_H
#define KV5500_SMS_H

#include <set>
#include <vector>

#include "sms.hpp"
#include "auto_array.hpp"

/// If you send prefix 0xfe and postfix 0x7e, phone send some data.
///
/// fe 14 7e            Get sms. (size 565?) When call again, get next sms.
///                     But I don't know total sms number. If got all sms and
///                     call again, it will get last sms.
///
/// Need root permission to access usb on FreeBSD, maybe also in GNU/Linux. :(
namespace KV5500 {

    class UsbDev;

    class SMSScanner {
    public:
        SMSScanner();

        void GetSMS(std::vector<SMS>& sms) const;
        bool GetSMS(SMS& sms, unsigned int num) const;
        unsigned int GetSMSNum() const;

        bool Scan(struct usb_device* dev);

    private:
        std::set<int> dateSet_;
        std::vector<SMS> smsContainer_;

        SMSScanner(const SMSScanner&);
        SMSScanner& operator=(const SMSScanner&);

        bool Request(UsbDev& udev);

        int Recv(UsbDev& udev);

        /// @brief Check existance by date string.
        bool CheckExist(const char* const buf);
    };

    typedef HG::AutoArray<const char>::Type ConstCharArrayPtr;

    /// @breif Get date string from buf.
    ConstCharArrayPtr GetSMSDateStr(const char* const buf);

    bool GetSMS(std::vector<SMS>& sms);
}

/// inline functions.
using namespace KV5500;

inline SMSScanner::SMSScanner()
{}

inline void SMSScanner::GetSMS(std::vector<SMS>& sms) const
{
    sms = smsContainer_;
}

inline bool SMSScanner::GetSMS(SMS& sms, unsigned int num) const
{
    if(smsContainer_.size() < num)
        return false;

    sms = smsContainer_[num];
}

inline unsigned int SMSScanner::GetSMSNum() const
{
    return smsContainer_.size();
}

#endif
